Total variation denoising can be used to approximate a given sequence of noisy observations by a piecewise constant sequence, with adaptively-chosen break points. An efficient linear-time algorithm for total variation denoising is provided here, based on Johnson (2013) tools:::Rd_expr_doi("10.1080/10618600.2012.681238").
Maintainer: Ryan Tibshirani ryantibs@gmail.com [copyright holder]
Other contributors:
Addison Hu [contributor]
Daniel McDonald [contributor]
Useful links: